# -*- coding: utf-8 -*-

#3b) Si supponga di avere a disposizione le due sequenze che corrispondono al 
# contenuto dei due cromosomi omologhi di un individuo (ovviamente, questa è 
# una semplificazione fatta ai soli fini dell'esercizio). In particolare, 
# il file "_luigi.fasta" contiene le due sequenze relative a Luigi.
# Utilizzando la funzione sviluppata al punto 3a), si determini la firma 
# genetica completa di Luigi relativamente ai motivi 'CAGCGA','CCTGGA' e 'GGGGCC'.
# Le varanti alleliche presenti in ciascun locus si dovranno indicare con una 
# tupla con tre elementi: il motif e il numero di ripetizioni per ciascuno dei 
# due alleli, mettendo il minore prima dell'altro. 
# Es: ('CAGCGA', 15, 18) ecc.
# Si scriva il risultato sul file "uso3.txt" con un locus per linea, ordinando 
# alfabeticamente i loci rispetto al relativo motivo base. Ciascuna variante 
# allelica dovrà essere stampata nel formato standard di output della relativa 
# tupla.


from soluzione3 import half_sign
import Bio.SeqIO as SeqIO

def merge_halves(h_sign1, h_sign2):
    """
    Utility function: given two half genetic signatures, return the complete 
    signature for the loci common to both the halves.
    """
    h1dict= dict(h_sign1)
    h2dict= dict(h_sign2)
    motifs = set(h1dict.keys())
    motifs = motifs.intersection( set(h2dict.keys()) )
    full_sign=[]
    for m in motifs:
        x = h1dict[m]
        y = h2dict[m]
        full_sign.append( (m, min(x,y), max(x,y)) )
    return sorted(full_sign)


if __name__=="__main__":
    
    infile = "_luigi.fasta"
    outfile = "uso3.txt"
    motifs = ['CAGCGA','CCTGGA', 'GGGGCC']    
    
    with open(infile,'r') as fin:
        sequit = SeqIO.parse(fin, "fasta")
        luigi1 = sequit.next()
        luigi2 = sequit.next()
    
    luigistr1=str(luigi1.seq)
    luigistr2=str(luigi2.seq)
    
    sign1 = half_sign(motifs, luigistr1)
    sign2 = half_sign(motifs, luigistr2)
    
    full_sign = merge_halves(sign1,sign2)
    
    with open(outfile,'w') as fout:
        for tup in full_sign:
            fout.write(str(tup)+"\n")
